--[[ This script is used to test the RDF/XML compliance.
It is made to run the W3C RDF APPROVED TEST CASES cf. http://www.w3.org/TR/rdf-testcases/
]]

--dumpErrorForError = true	--if true,dump the error returned by parser for errorXXX.rdf files
dumpFlag = true -- if true, dump the triples of the RDF/XML and the RDF/triples

assert( require('StrixStore') )
assert(require('webGet'))

rdf.open{uri='http://www.strixDB.com/',file='xml_test.db',truncate=true}
print('StrixStore Version=',rdf._VERSION)

function fileExists(fname)
	local f = io.open(fname,'r')
	local rc = f~=nil
	if rc then f:close() end
	return rc
end
	
function test(_,fpath)
	local name = fpath:sub(4,#fpath-4)
	local fntPath = fpath:sub(1,#fpath-4)..'.nt'

	local testName = fpath:match('/[-_%w]+/[-_%w]+%.rdf')
	
	local uriNT = 'http://www.w3.org/2000/10/rdf-tests/rdfcore' .. testName
	local uriXML = uriNT .. '.test'

	--print('Inserting', fpath)
	local error = rdf.graph.import {
		uri = uriXML, 
		file = fpath,
		luaError=false }
	
	if error~=nil then
		-- we get a parse error
		if fpath:match('error')~=nil then
			-- parse error is normal, it's a bad XML/RDF file
			print('	OK', testName)
			if dumpErrorForError==true then print('\t',error) end
			return
		end	
		-- we Got a problem
		print(error)
		print()print()
		
		return
	end
			
	--print('Inserting', fntPath)
	if fileExists(fntPath)==false then
		return 
	end
	
	error = rdf.graph.import {
		uri = uriNT, 
		file = fntPath,
		luaError=false }
	if error~=nil then
		-- we get a parse error
		print(error)
		print()print()
		return
	end
		
	-- comparison of graphs
	rdf.graph.relocate(uriXML, uriXML, uriNT)

	if rdf.graph.equal(uriXML,uriNT)==false then	
		print('--- comparison failure', testName)
		print()print()

		if dumpFlag==true then
			print('-----------------------')
			rdf.graph.export{uri=uriXML}
			print('-----------------------')
			rdf.graph.export{uri=uriNT}
			print()print()
		end
	else
		print('	OK', testName)
	end	
end

table.foreach( webGet.dirent("E:/RDF/RDF-samples",'r','.rdf'), test)
table.foreach( webGet.dirent("E:/RDF/RDF_TEST_CASES/APPROVED",'r','.rdf'), test)